@@ -1,6 +1,6 @@
 /*
   SDL_image:  An example image loading library for use with SDL
-  Copyright (C) 1997-2025 Sam Lantinga <slouken@libsdl.org>
+  Copyright (C) 1997-2026 Sam Lantinga <slouken@libsdl.org>
 
   This software is provided 'as-is', without any express or implied
   warranty.  In no event will the authors be held liable for any damages
@@ -25,6 +25,15 @@
 
 #ifdef LOAD_JXL
 
+#if defined(LOAD_JXL_DYNAMIC) && defined(SDL_ELF_NOTE_DLOPEN)
+SDL_ELF_NOTE_DLOPEN(
+    "libjxl",
+    "Support for JPEG XL images using libjxl",
+    SDL_ELF_NOTE_DLOPEN_PRIORITY_SUGGESTED,
+    LOAD_JXL_DYNAMIC
+)
+#endif
+
 #include <jxl/decode.h>
 
 
@@ -251,21 +260,17 @@ done:
 }
 
 #else
-#if defined(_MSC_VER) && _MSC_VER >= 1300
-#pragma warning(disable : 4100) /* warning C4100: 'op' : unreferenced formal parameter */
-#endif
 
 /* See if an image is contained in a data source */
 bool IMG_isJXL(SDL_IOStream *src)
 {
-    (void)src;
     return false;
 }
 
 /* Load a JXL type image from an SDL datasource */
 SDL_Surface *IMG_LoadJXL_IO(SDL_IOStream *src)
 {
-    (void)src;
+    SDL_SetError("SDL_image built without JXL support");
     return NULL;
 }
 
