@@ -1,6 +1,6 @@
 /*
   SDL_image:  An example image loading library for use with SDL
-  Copyright (C) 1997-2025 Sam Lantinga <slouken@libsdl.org>
+  Copyright (C) 1997-2026 Sam Lantinga <slouken@libsdl.org>
 
   This software is provided 'as-is', without any express or implied
   warranty.  In no event will the authors be held liable for any damages
@@ -503,9 +503,6 @@ done:
 }
 
 #else /* LOAD_LBM */
-#if defined(_MSC_VER) && _MSC_VER >= 1300
-#pragma warning(disable : 4100) /* warning C4100: 'op' : unreferenced formal parameter */
-#endif
 
 /* See if an image is contained in a data source */
 bool IMG_isLBM(SDL_IOStream *src)
@@ -516,6 +513,7 @@ bool IMG_isLBM(SDL_IOStream *src)
 /* Load an IFF type image from an SDL datasource */
 SDL_Surface *IMG_LoadLBM_IO(SDL_IOStream *src)
 {
+    SDL_SetError("SDL_image built without LBM support");
     return NULL;
 }
 
